Summary: A complete ODBC driver manager for Linux
Name: unixODBC64
Version: 2.2.14
Release: 3%{?dist}
Group: System Environment/Libraries
URL: http://www.unixODBC.org/
# Programs are GPL, libraries are LGPL, except News Server library is GPL.
License: GPLv2+ and LGPLv2+

Source: http://www.unixODBC.org/unixODBC-%{version}.tar.gz
Source1: odbcinst.ini
Source4: conffile.h
Source5: README.64bit

Patch1: depcomp.patch
Patch2: multilib-config.patch
Patch3: warning-cleanup.patch
Patch6: export-symbols.patch
Patch7: libtool-config.patch
Patch8: so-version-bump.patch
Patch9: keep-typedefs.patch
Patch10: odbcint64-config.patch
Patch11: enable-items.patch
Patch12: isql-fixes.patch
Patch13: libodbc64.patch

Conflicts: iodbc
# Base package must conflict with base unixODBC package;
# but note that the -libs subpackages do not conflict.
Conflicts: unixODBC

BuildRequires: readline-devel
BuildRequires: automake autoconf libtool libtool-ltdl-devel bison flex
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

# main package requires -libs subpackage
Requires: %{name}-libs%{?_isa} = %{version}-%{release}

%description
Install unixODBC64 if you want to access databases through ODBC, and you
need to use the corrected 64-bit ABI used in unixODBC 2.2.12 and up.
This base package provides documentation and command-line utility programs,
but is not required for client applications to make use of unixODBC64.
You will also need the mysql-connector-odbc64 package if you want to access
a MySQL database, and/or the postgresql-odbc64 package for PostgreSQL.

%package libs
Summary: The shared libraries required by programs that use unixODBC
Group: System Environment/Libraries

%description libs
The unixODBC64-libs package provides the essential shared libraries that
make up the unixODBC64 driver manager.  This is the minimum package to
install to use unixODBC64.

%package devel
Summary: Development files for programs which will use the unixODBC library
Group: Development/Libraries
Requires: %{name}%{?_isa} = %{version}-%{release}
Requires: %{name}-libs%{?_isa} = %{version}-%{release}
Conflicts: unixODBC-devel

%description devel
The unixODBC64 package can be used to access databases through ODBC
drivers. If you want to develop programs that will access data through
ODBC, you need to install this package.

%prep
%setup -q -n unixODBC-%{version}
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1

chmod 0644 Drivers/MiniSQL/*.c
chmod 0644 Drivers/nn/*.c
chmod 0644 Drivers/template/*.c
chmod 0644 doc/ProgrammerManual/Tutorial/*.html
chmod 0644 doc/lst/*
chmod 0644 include/odbcinst.h

# Blow away the embedded libtool and replace with build system's libtool.
# (We will use the installed libtool anyway, but this makes sure they match.)
rm -rf config.guess config.sub install-sh ltmain.sh libltdl
# this hack is so we can build with either libtool 2.2 or 1.5
libtoolize --install || libtoolize

%build
# clean up old moc files
(cd odbcinstQ4 && rm -f mC*.cpp)

aclocal
automake --add-missing
autoconf

# unixODBC 2.2.14 is not aliasing-safe
CFLAGS="%{optflags} -fno-strict-aliasing"
CXXFLAGS="$CFLAGS"
export CFLAGS CXXFLAGS

%configure --with-gnu-ld=yes --enable-threads=yes --enable-gui=no --enable-drivers --enable-ltdllib
make all

%install
rm -rf $RPM_BUILD_ROOT

make DESTDIR=$RPM_BUILD_ROOT install
install -m644 %{SOURCE1} $RPM_BUILD_ROOT%{_sysconfdir}

# multilib header hacks
# we only apply this to known Red Hat multilib arches, per bug #181335
case `uname -i` in
  i386 | x86_64 | ia64 | ppc | ppc64 | s390 | s390x | sparc | sparc64 )
    mv $RPM_BUILD_ROOT%{_includedir}/unixodbc_conf.h $RPM_BUILD_ROOT%{_includedir}/unixodbc_conf_`uname -i`.h
    rm -f unixodbc_conf.h
    sed s/CONFFILE/unixodbc_conf/ %{SOURCE4} >unixodbc_conf.h
    install -m 644 unixodbc_conf.h $RPM_BUILD_ROOT%{_includedir}
    ;;
  *)
    ;;
esac

# add some explanatory documentation
cp %{SOURCE5} README.64bit

# remove obsolete Postgres drivers from the package (but not the setup code)
rm -f $RPM_BUILD_ROOT%{_libdir}/libodbcpsql.so*

# don't want to install doc Makefiles as docs
find doc -name 'Makefile*' | xargs rm

# we do not want to ship static libraries
rm -f $RPM_BUILD_ROOT%{_libdir}/*.a

# remove unpackaged files from the buildroot
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/libltdl.*
rm -rf $RPM_BUILD_ROOT%{_datadir}/libtool

# initialize lists of .so files
find $RPM_BUILD_ROOT%{_libdir} -name "*.so.*" | sed "s|^$RPM_BUILD_ROOT||" > libs-so-list
find $RPM_BUILD_ROOT%{_libdir} -name "*.so"   | sed "s|^$RPM_BUILD_ROOT||" > devel-so-list

# These libraries are commonly dlopen'd, so provide versionless symlinks.
# To avoid conflicting with the unixODBC package, attach "64" to their names.
# Also, to avoid having unixODBC64-devel conflict with unixODBC-libs, we
# have to remove the versionless symlinks from the -devel package.
for lib in libodbc.so libodbcpsqlS.so libodbcmyS.so
do
    lib64=`echo $lib | sed 's/\.so/64.so/'`
    echo "%{_libdir}/$lib64" >> libs-so-list
    pushd $RPM_BUILD_ROOT%{_libdir}
    ln -s ${lib}.*.* $lib64
    rm ${lib}
    popd
    grep -v "/$lib$" devel-so-list > devel-so-list.x
    mv -f devel-so-list.x devel-so-list
done

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog NEWS doc
%{_bindir}/odbcinst
%{_bindir}/isql
%{_bindir}/dltest
%{_bindir}/iusql
%{_bindir}/odbc_config

%files libs -f libs-so-list
%defattr(-,root,root)
%doc README COPYING
%doc README.64bit
%config(noreplace) %{_sysconfdir}/odbc*

%files devel -f devel-so-list
%defattr(-,root,root)
%{_includedir}/*

%post libs -p /sbin/ldconfig
%postun libs -p /sbin/ldconfig

%changelog
* Tue Nov 29 2011 Tom Lane <tgl@redhat.com> 2.2.14-3
- Drat, forgot to teach conffile.h about ia64 multilib support
Resolves: #757126

* Mon Oct 17 2011 Tom Lane <tgl@redhat.com> 2.2.14-2
- Treat ia64 as a multilib architecture, because rpmdiff has started to
  whinge about it
Related: #742597

* Mon Oct 10 2011 Tom Lane <tgl@redhat.com> 2.2.14-1
- Constructed from current Fedora package, removing -kde subpackage because
  2.2.14 seems to need a newer version of Qt than RHEL-5 provides.
- Split libraries into a -libs subpackage to allow installation concurrent
  with the original unixODBC package (or at least its -libs subpackage).
Resolves: #742597
